@@ -18,7 +18,7 @@ use Test::BrewBuild::BrewCommands;
 use Test::BrewBuild::Dispatch;
 use Test::BrewBuild::Tester;
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 
 my $log;
 my $bcmd;
@@ -545,7 +545,7 @@ sub _create_log {
     my ($self, $level) = @_;
 
     $self->{log} = Logging::Simple->new(
-        name  => 'Test::BrewBuild',
+        name  => 'BrewBuild',
         level => defined $level ? $level : 0,
     );
 
@@ -1092,17 +1092,6 @@ Displays the C<brewbuild> command line usage information.
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
 
-=head1 CONTRIBUTING
-
-Any and all feedback and help is appreciated. A Pull Request is the preferred
-method of receiving changes (L<https://github.com/stevieb9/p5-test-brewbuild>),
-but regular patches through the bug tracker, or even just email discussions are
-welcomed.
-
-=head1 BUGS
-
-L<https://github.com/stevieb9/p5-test-brewbuild/issues>
-
 =head1 SEE ALSO
 
 Berrybrew for Windows:
@@ -1115,7 +1104,7 @@ L<http://perlbrew.pl>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Steve Bertrand.
+Copyright 2017 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
