@@ -4,7 +4,7 @@ use warnings;
 
 use version;
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 
 my $log;
 
@@ -15,7 +15,7 @@ sub new {
 
     $self->{min_perl_version} = '5.8.1';
 
-    $self->{log} = $plog->child('Test::BrewBuild::BrewCommands');
+    $self->{log} = $plog->child('BrewCommands');
     $log = $self->{log};
     $log->_6("constructing new Test::BrewBuild::BrewCommands object");
 
@@ -240,20 +240,9 @@ Returns 0 if on Unix, and 1 if on Windows.
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
 
-=head1 CONTRIBUTING
-
-Any and all feedback and help is appreciated. A Pull Request is the preferred
-method of receiving changes (L<https://github.com/stevieb9/p5-test-brewbuild>),
-but regular patches through the bug tracker, or even just email discussions are
-welcomed.
-
-=head1 BUGS
-
-L<https://github.com/stevieb9/p5-test-brewbuild/issues>
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Steve Bertrand.
+Copyright 2017 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
