@@ -9,15 +9,17 @@ use Cwd qw(getcwd);
 use IO::Socket::INET;
 use Logging::Simple;
 use Parallel::ForkManager;
+use POSIX;
 use Storable;
 use Test::BrewBuild;
 use Test::BrewBuild::Git;
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 
 $| = 1;
 
-my $log;
+my ($log, $last_run_status, $results_returned, $lcd);
+$ENV{BB_RUN_STATUS} = 'PASS';
 
 sub new {
     my ($class, %args) = @_;
@@ -31,7 +33,9 @@ sub new {
         $self->{debug} = $args{debug};
     }
 
+    $self->{auto} = defined $args{auto} ? $args{auto} : undef;
     $self->{forks} = defined $args{forks} ? $args{forks} : 4;
+    $self->{rpi} = defined $args{rpi} ? $args{rpi} : undef;
 
     my $log = $log->child('new');
     $log->_5("instantiating new Test::BrewBuild::Dispatch object");
@@ -47,50 +51,137 @@ sub auto {
 
     $log->_5("commencing auto run dispatch sequence");
 
-    my $git = Test::BrewBuild::Git->new;
+    $last_run_status = $ENV{BB_RUN_STATUS};
+
+    if (! defined $params{repo}){
+        $log->_5("auto() requires the --repo param sent in. Can't continue...");
+        croak "auto mode requires the repository parameter sent in.\n";
+    }
+
     my $sleep = defined $self->{auto_sleep} ? $self->{auto_sleep} : 60;
 
     my $runs = $params{auto};
     my $run_count = 1;
 
-    $log->_7("$runs auto runs planned");
+    $log->_7("$runs auto runs planned") if $runs > 0;
+    $log->_7("continuous integration mode enabled") if $runs == 0;
 
-    my $err = capture_stderr {
-            $git->status;
-    };
-
-    if ($err =~ /fatal: Not a git repository/){
-        $log->_5("auto failed due to not being in a git repo");
-        croak "not in a Git repository... can't continue.";
-    }
+    my $git = Test::BrewBuild::Git->new;
 
     while (1){
-        my $status = $git->status(repo => $params{repo});
-        my $local_sum = $git->revision(repo => $params{repo});
-        my $remote_sum = $git->revision(remote => 1, repo => $params{repo});
 
-        if ($status || $local_sum eq $remote_sum){
-            $log->_6("local and remote commit sums match. Nothing to do");
-            sleep $sleep;
-            next;
+        if (! $runs){
+            $log->_6("commencing run $run_count");
+        }
+        else {
+            $log->_6("commencing run $run_count of $runs");
         }
 
-        $log->_6("commit sums don't match... commencing run $run_count of $runs");
-
         my $results = $self->dispatch(%params);
 
+        my @short_results = $results =~ /(5\.\d{1,2}\.\d{1,2} :: \w{4})/g;
+
+        print "$_\n" for @short_results;
+
+        if (grep /FAIL/, @short_results){
+            $log->_5("auto run status: FAIL");
+            $ENV{BB_RUN_STATUS} = 'FAIL';
+            $results_returned = 1;
+        }
+        elsif (grep /PASS/, @short_results){
+            $log->_5("auto run status: PASS");
+            $ENV{BB_RUN_STATUS} = 'PASS';
+            $results_returned = 1;
+        }
+        else {
+            $log->_5("no results returned");
+            $results_returned = 0;
+        }
+
+        my $commit = $git->revision(remote => 1, repo => $params{repo});
+        $commit = substr $commit, 0, 8;
+        
+        if (1){#}($ENV{BB_RUN_STATUS} ne $last_run_status){
+            $log->_7("current and last runs status are different. Running " .
+                     "plugins if available"
+            );
+
+            if ($self->{rpi}){
+                $log->_7("RPi specific testing enabled");
+
+                if ($ENV{BB_RPI_LCD}){
+                    my @pins = split /,/, $ENV{BB_RPI_LCD};
+                    if (@pins == 6){
+                        if ($results_returned){
+                            my $time = strftime("%Y-%m-%d %H:%M:%S\n", localtime(time));
+                            
+                            $lcd = _lcd(@pins) if ! defined $lcd;
+
+                            $lcd->position(0, 0);
+                            $lcd->print($time);
+
+                            $lcd->position(0, 1);
+                            $lcd->print("$ENV{BB_RUN_STATUS}");
+
+                            $lcd->position(8, 1);
+                            $lcd->print($commit);
+                        }
+                    }
+                    else {
+                        $log->_1(
+                            "in --rpi mode, but BB_RPI_LCD env var not set " .
+                            "correctly"
+                        );
+                        warn "bbdispatch is in --rpi mode, but the BB_RPI_LCD ".
+                             " env var isn't set. See the documentation...\n";
+                    }
+                }
+                else {
+                    $log->_7("in --rpi mode, but BB_RPI_LCD env var not set");
+                }
+            }
+            else {
+                $log->_7("not in --rpi mode");
+            }
+        }
+
         $log->_6(
             "auto run complete. Sleeping, then restarting if more runs required"
         );
 
-        print $results;
-
-        exit() if $run_count >= $runs;
+        exit() if $run_count >= $runs && $runs != 0;
         $run_count++;
 
         sleep $sleep;
     }
 }
+sub _lcd {
+    # used only for doing RPi::WiringPi unit test runs in auto mode
+
+    my @pins = @_;
+
+    require RPi::LCD;
+
+    my $lcd = RPi::LCD->new;
+
+    $lcd->init(
+        rows    => 2,
+        cols    => 16,
+        bits    => 4,
+        rs      => $pins[0],
+        strb    => $pins[1],
+        d0      => $pins[2],
+        d1      => $pins[3],
+        d2      => $pins[4],
+        d3      => $pins[5],
+        d4      => 0,
+        d5      => 0,
+        d6      => 0,
+        d7      => 0
+    );
+
+    return $lcd;
+}
 sub dispatch {
     my ($self, %params) = @_;
 
@@ -175,7 +266,7 @@ sub dispatch {
             $return .= "$build->{data}\n";
         }
     }
-    $log->_7("returning results...");
+    $log->_7("returning results if available...");
     return $return;
 }
 sub _config {
@@ -295,7 +386,7 @@ sub _fork {
                 1;
             };
 
-            if (! $ok){
+            if (! $ok && ! defined $self->{auto}){
                 $log->_0("errors occurred... check your command line " .
                          "string for invalid args. You sent in: $cmd"
                 );
@@ -376,7 +467,8 @@ dispatcher dispatches to.
 
 This function will spin off a continuous run of C<dispatch()> runs, based on
 whether the commit revision checksum locally is different than that from the
-remote. It takes all of the same parameters as C<dispatch()>.
+remote. It takes all of the same parameters as C<dispatch()>, and the
+C<-r|--repo> parameter is mandatory.
 
 There is also a configuration file directive in the C<[Dispatch]> section,
 C<auto_sleep>, which dictates how many seconds to sleep in between each run. The
@@ -386,20 +478,9 @@ default is C<60>, or one minute.
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
 
-=head1 CONTRIBUTING
-
-Any and all feedback and help is appreciated. A Pull Request is the preferred
-method of receiving changes (L<https://github.com/stevieb9/p5-test-brewbuild>),
-but regular patches through the bug tracker, or even just email discussions are
-welcomed.
-
-=head1 BUGS
-
-L<https://github.com/stevieb9/p5-test-brewbuild/issues>
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Steve Bertrand.
+Copyright 2017 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
