@@ -7,7 +7,7 @@ use Carp qw(croak);
 use Logging::Simple;
 use LWP::Simple qw(head);
 
-our $VERSION = '2.14';
+our $VERSION = '2.15';
 
 my $log;
 
@@ -16,7 +16,7 @@ sub new {
     my $self = bless {}, $class;
 
     $log = Logging::Simple->new(
-        name => 'Test::BrewBuild::Git',
+        name => 'Git',
         level => 0
     );
 
@@ -70,7 +70,7 @@ sub clone {
 
     $log->child('clone')->_7("initiating remote repo clone");
 
-    if ($repo =~ /http/ && ! head($repo)){
+    if ($repo !~ /https/){
         $log->child('clone')->_2("git clone failed, repo doesn't exist");
         croak "repository $repo doesn't exist; can't clone...\n";
     }
@@ -104,10 +104,18 @@ sub revision {
     my $csum;
 
     if (! $remote) {
-        $csum = `$git rev-parse HEAD`;
+        $csum = `"$git" rev-parse HEAD`;
     }
     else {
-        $csum = `$git rev-parse origin/master`;
+        # void capture, as there's unneeded stuff going to STDERR
+        # on the ls-remote call
+
+        capture_stderr {
+            my $sums = `"$git" ls-remote`;
+            if ($sums =~ /([A-F0-9]{40})\s+HEAD/i){
+                $csum = $1;
+            }
+        }
     }
 
     chomp $csum;
@@ -228,20 +236,9 @@ regarding commits, and false if we're ahead.
 
 Steve Bertrand, C<< <steveb at cpan.org> >>
 
-=head1 CONTRIBUTING
-
-Any and all feedback and help is appreciated. A Pull Request is the preferred
-method of receiving changes (L<https://github.com/stevieb9/p5-test-brewbuild>),
-but regular patches through the bug tracker, or even just email discussions are
-welcomed.
-
-=head1 BUGS
-
-L<https://github.com/stevieb9/p5-test-brewbuild/issues>
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2016 Steve Bertrand.
+Copyright 2017 Steve Bertrand.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
